;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;
; // George Mason University, CSS 610 - Fall 2016
; // Modeling a Victim-Centered Approach for Detection of Human Trafficking Among Migrant Flows
; //
; // @author Brant Horio & Kyle Ballard, George Mason University (2016)
;
; // Published:
; // Brant M. Horio and Kyle M. Ballard. Modeling a Victim-Centered Approach for Detection of Human Trafficking
; // Victims within Migration Flows, Policy and Complex Systems. Volume 3, Number 2, Fall 2017: Washington, D.C.
; // doi: 10.18278/jpcs.3.1.9
;
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

breed [ migrants migrant ]

;// global variables are assumed to represent the border authority and their policies, since we only assume one "agent."
globals
[
  g.migrantsProcessed            ;// count of migrants processed by the border authorities.
  g.migrantsAccepted             ;// count of migrants allowed entry into country/asylum process/etc.
  g.migrantsRejected             ;// count of migrants not allowed entry (e.g., deported)

  g.victimPopulation             ;// count of migrant trafficking victims
  g.victimsIdentified            ;// count of migrant trafficking victims successfully "cooperating" with the State.
  g.victimsMissed                ;// count of migrant trafficking victims missed (not detected)
  g.victimsWillingButMissed      ;// count of migrant trafficking victims willing to cooperate, but were rejected by the State.

  g.policyStatus                 ;// reflects the accepted migrant count being below ("Accepting") or above ("Rejecting") quota.
]

migrants-own
[
  m.isVictim?                    ;// boolean for if the migrant is a trafficking victim.

  m.motive                       ;// migrant motive as "Fleeing" conflict or "Seeking" economic gain/stability.
  m.skills                       ;// migrant's marketable skill level ("low" or "high") that is of interest to the State.
  m.vulnerability                ;// migrant's vulnerability level ("low" or "high") that represents susceptibility to trafficking.
  m.strategy                     ;// migrant's current strategy to cooperate or defect with the border authorities.

  m.isUpdated?                   ;// boolean for if the migrant has updated their intended strategy yet.
  m.hasInteracted?               ;// boolean for if the migrant has interacted with the authorities yet or not.
  m.interactionOutcome           ;// outcome from migrant interaction; "Accepted", "Rejected", or "na".
]

;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
; MODEL METHODS.
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

;/**
; * Setup the model.
; */
to model.setup
  clear-all

  if (gui.useSeed = true)
  [
    random-seed (gui.randomSeed)
  ]

  ;// initialize model globals
  model.initGlobals

  ;// instantiate the migrants initially with a hollow square.
  set-default-shape migrants "square 2"

  ;// instantiate the migrant population and assign agent attributes.
  m.instantiatePopulation

  set g.victimPopulation ( count migrants with [m.isVictim? = true] )

  ;// color the migrant agent according to its strategy.
  m.visualizeStrategy

  reset-ticks
end

;/**
; * Initialize the global variables.
; */
to model.initGlobals
  set g.migrantsProcessed 0             ;// initialize the count of migrants processed to zero.
  set g.migrantsAccepted 0              ;// initialize the count of migrants accepted to zero.
  set g.migrantsRejected 0              ;// initialize the count of migrants rejected to zero.

  set g.victimPopulation 0              ;// initialize the count of the victim population to zero.
  set g.victimsIdentified 0             ;// initialize the count of victims successfully identified to zero.
  set g.victimsMissed 0                 ;// initialize the count of victims missed to zero.
  set g.victimsWillingButMissed 0       ;// initialize the count of victims willing to cooperate but are rejected by the State to zero.

  set g.policyStatus "Accepting"
end

;/**
; * Main.
; */
to model.go
  ;// stop the model run after all migrants have been processed.
  if (ticks = (count migrants)) [ stop ]

  model.resetMigrants

  ;// interact migrant population with the border authorities, one at a time (one per tick).
  m.interactWithAuthorities

  ;// then ask all migrants who haven't interacted with authorities yet, to imitate their best neighbor/linked agents.
  m.updateStrategyIntention

  ;// given migrant entries against quota, check status and update State/authority strategy accordingly.
  s.updateStatePosition

  ;// refresh the color of the world given the strategic decisions/intentions of the agents.
  m.visualizeStrategy

  set g.victimsWillingButMissed ( count migrants with [(m.strategy = "Cooperate") and (m.interactionOutcome = "Rejected") and (m.isVictim? = true)] )

  tick

end

;/**
; * Sprouts a new migrant agent on a given patch and links it to the specified agent passed in as an argument.
; */
to model.createNetworkNode [ oldNode ]

  ;// instantiate a migrant agent, one at a time.
  sprout-migrants 1
  [
    set heading 0

    set m.isUpdated? false                  ;// initialize the migrant agent with not having updated their intended strategy yet.

    set m.hasInteracted? false              ;// intialize the migrant agent with not having interacted with authorities yet.
    set m.interactionOutcome "na"           ;// initailize the migrant agent with not interaction outcome yet.

    ;// assign the migrant into the preferrential attachment network structure of the migrant population.
    if oldNode != nobody
    [
      create-link-with oldNode              ;// establish a link with the specified agent.
    ]

    ;// ASSIGN MIGRANT VARIABLES
    ;// declare local variable and assign with a uniform random draw from range U[0, 1]
    let _role (random-float 1)

    ;// TRAFFICKING VICTIM STATUS
    ;// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    ;// based on role, determine if the migrant's motive is fleeing conflict or seeking economic stability/resources.
    ifelse (_role < gui.proportionVictims)
    [
      set m.isVictim? true
      set m.vulnerability "High"
      set shape "target"
    ]
    [
      set m.isVictim? false
      set m.vulnerability "Low"
    ]

    ;// MIGRANT SKILL LEVEL
    ;// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    ;// based on role, determine the migrant's skill level.
    set _role (random-float 1)
    ifelse (_role < gui.probabilityHighSkill)
    [
      set m.skills "High"
    ]
    [
      set m.skills "Low"
    ]

    ;// MIGRANT MOTIVE
    ;// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    ;// based on role, determine if the migrant's motive is fleeing conflict or seeking economic stability/resources.
    set _role (random-float 1)
    ifelse (_role < gui.proportionFleeing)
    [
      set m.motive "Fleeing"
    ]
    [
      set m.motive "Seeking"
    ]

    ;// MIGRANT INITIAL STRATEGY
    ;// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    ;// based on role, determine if the initial agent strategy is to cooperate or not with the border authorities.
    set _role (random-float 1)
    ifelse (_role < gui.proportionCooperate)
    [
      set m.strategy "Cooperate"
    ]
    [
      set m.strategy "Deceive"
    ]
  ]
end

;/**
; * Returns a random link and then chooses one of the link ends.
; */
to-report model.findConnectionNode
  report [one-of both-ends] of one-of links
end


to model.resetMigrants
  ask migrants with [ m.hasInteracted? = false ]
  [
    set m.isUpdated? false
  ]
end

;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
; STATE/AUTHORITY AGENT METHODS.
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

;/**
; * Checks on current state of migrant situation and if quota is reached, flag is set to deny all new migrants.
; */
to s.updateStatePosition

  ifelse (g.migrantsProcessed <= gui.migrantEntryQuota)
  [
    set g.policyStatus "Accepting"
  ]
  [
    set g.policyStatus "Rejecting"
  ]

end

;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
; MIGRANT AGENT METHODS.
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

;/**
; * Instantiates the migrant population and connects them via preferential attachment into a network.
; */
to m.instantiatePopulation

  ;// make the initial network of two turtles and an edge.
  ask one-of patches [ model.createNetworkNode nobody ]           ;;// first node, unattached.
  ask one-of patches [ model.createNetworkNode (turtle 0) ]         ;;// second node, attached to first node.

  ;// for every other patch, instantiate the rest of the population and link them to the preferential attachment network.
  ask patches with [not any? turtles-here]
  [
    model.createNetworkNode ( model.findConnectionNode )
  ]

  ;// hide the links since we have them spaced as a cellular automata and the link visuals are not useful.
  ask links [ hide-link ]
end

;/**
; * Migrant method to color the agent according to their current strategy.
; */
to m.visualizeStrategy
  ;// ask all migrants to color their agent on the interface.
  ask migrants
  [
    ifelse (m.strategy = "Cooperate")
    [
      set color yellow            ;// color for migrants that will cooperate.
    ]
    [
      set color red               ;// color for migrants that will not cooperate and attempt to deceive.
    ]
  ]
end

;/**
; * Interact with the border authorities.
; */
to m.interactWithAuthorities

  ;// if a migrant has not interacted with the border authorities yet, process the migrant agent.
  ask one-of migrants with [ m.hasInteracted? = false ]
  [
    ifelse (g.migrantsAccepted < gui.migrantEntryQuota)             ;// quota is not full yet, thus determine if migrant is accepted by the policy setting.
    [
      ;// QUOTA IS NOT YET FULL -- STATE MAY CONSIDER ACCEPTING MIGRANT ENTRIES
      ;// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

      ;// first check to see if victim-centered approach is being employed, since they might be accepted regardless of State policy.
      ;// note that migrant victim is accepted, IFF they are willing to cooperate!
      if ((gui.useVictimCentered = true) and (m.vulnerability = "High") and (m.strategy = "Cooperate"))
      [
        set m.interactionOutcome "Accepted"
        set shape "victim_identified"                             ;// successful identification of victim.
        set g.victimsIdentified (g.victimsIdentified + 1)           ;//

        set g.migrantsAccepted ( g.migrantsAccepted + 1 )           ;// update accepted count.
      ]

      if (m.interactionOutcome != "Accepted")                       ;// now assess the policy decisions (including the victim if they failed to self-identify)
      [
        if (gui.statePolicy = "Economic")
        [
          ;// now check for and accept high economic valued migrants based on their skill level.
          ifelse (m.skills = "High")
          [
            set m.interactionOutcome "Accepted"                   ;// migrant is accepted as a high-skilled asset.
            ifelse (m.isVictim? = true)
            [
              set shape "victim_missed"                           ;// even if accepted as a migrant, missed identification as a victim.
              set g.victimsMissed (g.victimsMissed + 1)             ;//
            ]
            [
              set shape "square"
            ]

            set g.migrantsAccepted ( g.migrantsAccepted + 1 )       ;// update accepted count.
          ]
          [
            set m.interactionOutcome "Rejected"                   ;// migrant did not cooperate as a victim, and is low-skilled.
            ifelse (m.isVictim? = true)
            [
              set shape "victim_missed"
              set g.victimsMissed (g.victimsMissed + 1)             ;//
            ]
            [
              set shape "x"
            ]

            set g.migrantsRejected ( g.migrantsRejected + 1 )       ;// update rejected count.
          ]
        ]

        if (gui.statePolicy = "Humanitarian")
        [
          ;// now check for and accept high economic valued migrants based on if they are fleeing conflict.
          ifelse (m.motive = "Fleeing")
          [
            set m.interactionOutcome "Accepted"                   ;// migrant is accepted as a high-skilled asset.
            ifelse (m.isVictim? = true)
            [
              set shape "victim_missed"                           ;// even if accepted as a migrant, missed identification as a victim.
              set g.victimsMissed (g.victimsMissed + 1)             ;//
            ]
            [
              set shape "square"
            ]

            set g.migrantsAccepted ( g.migrantsAccepted + 1 )       ;// update accepted count.
          ]
          [
            set m.interactionOutcome "Rejected"                   ;// migrant did not cooperate as a victim, and is low-skilled.
            ifelse (m.isVictim? = true)
            [
              set shape "victim_missed"
              set g.victimsMissed (g.victimsMissed + 1)             ;//
            ]
            [
              set shape "x"
            ]

            set g.migrantsRejected ( g.migrantsRejected + 1 )       ;// update rejected count.
          ]
        ]
      ]
    ]
    [
      ;// QUOTA IS FULL -- CANNOT ACCEPT ADDITIONAL MIGRANT ENTRIES
      ;// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

      set m.interactionOutcome "Rejected"                         ;// quota full, thus migrant is rejected.

      ifelse (m.isVictim? = true)
      [
        set shape "victim_missed"
        set g.victimsMissed (g.victimsMissed + 1)                   ;//
      ]
      [
        set shape "x"
      ]

      set g.migrantsRejected ( g.migrantsRejected + 1 )             ;// update rejected count.
    ]

    ;// UPDATE FIRST ORDER NEIGHBORS AND CONNECTIONS
    ;// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    ;// Update 1st order neighbors and network connections based on outcome.
    ;// based on status of Moore neighborhood and preferrential attachment connections, update list of neighbors to influence.
    let _1stOrderNeighbors (no-turtles)
    set _1stOrderNeighbors (turtle-set _1stOrderNeighbors (migrants-on neighbors))
    set _1stOrderNeighbors (turtle-set _1stOrderNeighbors link-neighbors)

    let _this.strategy (m.strategy)
    let _this.motive (m.motive)
    let _this.skills (m.skills)

    ask _1stOrderNeighbors
    [
      ;// imitate neighbor majority, based on comparisons to the 1st order connection to the recent interaction outcome.
      m.imitateWeightedNeighborMajority (_this.strategy) (_this.motive) (_this.skills)

      set m.isUpdated? true                                 ;// sets boolean to note that these agents have updated their strategy due to 1st order feedback.
    ]

    set m.hasInteracted? true                                 ;// set the boolean for interation to True.
    set g.migrantsProcessed (g.migrantsProcessed + 1)           ;// update the total count of migrants processed.
  ]

end

;/**
; * Update all other migrants (outside of 1st order connections from the most recent interaction) with respect
; * to their intended strategy for interacting with the border authorities.
; */
to m.updateStrategyIntention

  ;// for all migrants who have not interacted with the border authorities yet, and are not 1st order connected to recent interaction.
  ask migrants with [ (m.hasInteracted? = false) or (m.isUpdated? = false) ]
  [
    m.imitateNeighborMajority
  ]

end

;/**
; * Update the migrant's strategy intention for migrants with no 1st-order connection to most recent interaction outcome.
; */
to m.imitateNeighborMajority

  let _neighbors (no-turtles)                                ;// instantiate an empty agentset.

  ask migrants-on neighbors
  [
    let _this.agent (self)
    set _neighbors (turtle-set _neighbors _this.agent)       ;// add Moore neighbors to agentset.
  ]

  ask link-neighbors
  [
    let _this.agent (self)
    set _neighbors (turtle-set _neighbors _this.agent)       ;// add network linked agents to agentset.
  ]

  let _cooperators (count _neighbors with [m.strategy = "Cooperate"])
  let _deceivers (count _neighbors with [m.strategy = "Deceive"])

  let _orig (m.strategy)                                     ;// for debug print statement.

  if (_cooperators != _deceivers)                            ;// only imitate majority if majority exists -- in case of tie, keep initial strategy.
  [
    ifelse (_cooperators > _deceivers)
    [
      set m.strategy "Cooperate"                           ;// majority influence to cooperate.
    ]
    [
      set m.strategy "Deceive"                             ;// majority influence to deceive.
    ]
  ]
end

;/**
; * Update the migrant's strategy intention, with weightings accounted for.
; */
to m.imitateWeightedNeighborMajority [ _recentStrategy _recentMotive _recentSkills ]

  let _neighborsOf1stOrder (no-turtles)                                      ;// instantiate an empty agentset.

  ask migrants-on neighbors
  [
    let _this.agent (self)
    set _neighborsOf1stOrder (turtle-set _neighborsOf1stOrder _this.agent)   ;// add Moore neighbors to agentset.
  ]

  ask link-neighbors
  [
    let _this.agent (self)
    set _neighborsOf1stOrder (turtle-set _neighborsOf1stOrder _this.agent)   ;// add network linked agents to agentset.
  ]

  let _cooperatorCount 0
  let _deceiverCount 0

  let _this.motive (m.motive)
  let _this.skills (m.skills)
  let _this.vulnerability (m.vulnerability)

  ;// first, have the 1st order neighbor check to see if recent interaction was similar to them.
  if (gui.statePolicy = "Economic")
  [
    ;// if the interacting migrant was similar w.r.t., skills, then weight them accordingly.
    ifelse (m.skills = _recentSkills)
    [
      ;// agent is similar to recent interaction, therefore weight the count by some factor.
      if (_recentStrategy = "Cooperate")
      [
        set _cooperatorCount ((_cooperatorCount + 1) * gui.similarityInfluenceWeighting)
      ]

      if (_recentStrategy = "Deceive")
      [
        set _deceiverCount ((_deceiverCount + 1) * gui.similarityInfluenceWeighting)
      ]
    ]
    [
      ;// agent is dissimilar to recent interaction, therefore count as one.
      if (_recentStrategy = "Cooperate")
      [
        set _cooperatorCount (_cooperatorCount + 1)
      ]

      if (_recentStrategy = "Deceive")
      [
        set _deceiverCount (_deceiverCount + 1)
      ]
    ]
  ]

  if (gui.statePolicy = "Humanitarian")
  [
    ;// if the interacting migrant was similar w.r.t., skills, then weight them accordingly.
    ifelse (m.motive = _recentMotive)
    [
      ;// agent is similar to recent interaction, therefore weight the count by some factor.
      if (_recentStrategy = "Cooperate")
      [
        set _cooperatorCount ((_cooperatorCount + 1) * gui.similarityInfluenceWeighting)
      ]

      if (_recentStrategy = "Deceive")
      [
        set _deceiverCount ((_deceiverCount + 1) * gui.similarityInfluenceWeighting)
      ]
    ]
    [
      ;// agent is dissimilar to recent interaction, therefore count as one.
      if (_recentStrategy = "Cooperate")
      [
        set _cooperatorCount (_cooperatorCount + 1)
      ]

      if (_recentStrategy = "Deceive")
      [
        set _deceiverCount (_deceiverCount + 1)
      ]
    ]
  ]

  ;// next, account for all the other neighbors of the 1st order agent and count them up one-for-one.
  ;// NOTE: this includes counting the recent interacting agent again, so multiplier accounts for this counting overlap.
  let _cooperators (count _neighborsOf1stOrder with [m.strategy = "Cooperate"])
  let _deceivers (count _neighborsOf1stOrder with [m.strategy = "Deceive"])

  ;// now add into the _cooperator and _deceiver counts, the weighted counts.
  set _cooperators (_cooperators + _cooperatorCount)
  set _deceivers (_deceivers + _deceiverCount)

  let _orig (m.strategy)                                     ;// for debug print statement.

  if (_cooperators != _deceivers)                            ;// only imitate majority if majority exists -- in case of tie, keep initial strategy.
  [
    ifelse (_cooperators > _deceivers)
    [
      set m.strategy "Cooperate"                           ;// majority influence to cooperate.
    ]
    [
      set m.strategy "Deceive"                             ;// majority influence to deceive.
    ]
  ]

end



;/**
; * Update the payoffs for the agents with 1st order connections (i.e., Moore neighborhood, links) to
; * agent that just completed their interaction.
; */
to m.updatePayoffMatrices

  ;; do the voting thing and imitate the best...???


end
@#$#@#$#@
GRAPHICS-WINDOW
293
10
793
511
-1
-1
12.0
1
10
1
1
1
0
0
0
1
-20
20
-20
20
1
1
1
ticks
60.0

BUTTON
3
381
78
452
Setup
model.setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
167
381
284
454
Run
model.go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

BUTTON
83
381
162
453
Step
model.go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

MONITOR
804
10
933
55
Migrant Population
count migrants
3
1
11

SLIDER
5
115
217
148
gui.proportionCooperate
gui.proportionCooperate
0.0
1
0.51
0.01
1
NIL
HORIZONTAL

TEXTBOX
9
10
282
82
Modeling a Victim-Centered Approach for Detection of Human Trafficking Among Migrant Flows\n____________________________________________
14
0.0
1

SLIDER
5
151
217
184
gui.proportionFleeing
gui.proportionFleeing
0.0
1
0.5
0.01
1
NIL
HORIZONTAL

SLIDER
4
223
218
256
gui.proportionVictims
gui.proportionVictims
0.0
1
0.055
0.01
1
NIL
HORIZONTAL

MONITOR
805
58
933
103
Migrants Processed
count migrants with [m.hasInteracted? = true]
17
1
11

MONITOR
805
106
934
151
Migrants Waiting
count migrants with [m.hasInteracted? = false]
17
1
11

SLIDER
3
539
286
572
gui.migrantEntryQuota
gui.migrantEntryQuota
0
1681
51.0
1
1
migrants
HORIZONTAL

MONITOR
293
534
387
579
Victim Population
g.victimPopulation
17
1
11

MONITOR
389
534
484
579
Victims Identified
g.victimsIdentified
17
1
11

MONITOR
695
534
795
579
Victims Missed
g.victimsMissed
17
1
11

CHOOSER
3
491
123
536
gui.statePolicy
gui.statePolicy
"Economic" "Humanitarian"
1

SLIDER
4
187
217
220
gui.probabilityHighSkill
gui.probabilityHighSkill
0
1
0.33
0.01
1
NIL
HORIZONTAL

SWITCH
128
499
285
532
gui.useVictimCentered
gui.useVictimCentered
0
1
-1000

TEXTBOX
9
91
159
109
MIGRANT VARIABLES
11
0.0
1

TEXTBOX
9
309
159
327
MODEL CONTROLS
11
0.0
1

TEXTBOX
6
470
216
498
STATE / AUTHORITY VARIABLES
11
0.0
1

PLOT
806
154
1224
370
Migrant Intended Strategy
time
% of migrants
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"Cooperate" 1.0 0 -13345367 true "" "plot ((count migrants with [m.strategy = \"Cooperate\"]) / (count migrants))"
"Deceive" 1.0 0 -2674135 true "" "plot ((count migrants with [m.strategy = \"Deceive\"]) / (count migrants))"

PLOT
806
372
1224
576
Victim Intended Strategy
time
% of victims
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"Cooperate" 1.0 0 -13345367 true "" "plot (count migrants with [(m.isVictim? = true) and (m.strategy = \"Cooperate\")]) / (count migrants with [m.isVictim? = true])"
"Deceive" 1.0 0 -2674135 true "" "plot (count migrants with [(m.isVictim? = true) and (m.strategy = \"Deceive\")]) / (count migrants with [m.isVictim? = true])"

MONITOR
947
10
1075
55
Migrant Quota
gui.migrantEntryQuota
17
1
11

MONITOR
947
58
1076
103
Migrants Accepted
g.migrantsAccepted
17
1
11

MONITOR
948
106
1077
151
Migrants Rejected
g.migrantsRejected
17
1
11

MONITOR
485
534
693
579
Victims willing to Cooperate but Rejected
g.victimsWillingButMissed
17
1
11

SLIDER
5
259
218
292
gui.similarityInfluenceWeighting
gui.similarityInfluenceWeighting
0
5
1.5
0.25
1
NIL
HORIZONTAL

SWITCH
5
330
129
363
gui.useSeed
gui.useSeed
0
1
-1000

INPUTBOX
135
315
253
375
gui.randomSeed
12345.0
1
0
Number

@#$#@#$#@
## WHAT IS IT?

Brant M. Horio and Kyle M. Ballard. Modeling a Victim-Centered Approach for Detection of Human Trafficking Victims within Migration Flows, Policy and Complex Systems. Volume 3, Number 2, Fall 2017: Washington, D.C. doi: 10.18278/jpcs.3.1.9

Human trafficking—the use of force, fraud, or coercion to compel individuals into sex trafficking or forced labor—is a global problem. It is challenging to determine the magnitude of this “hidden crime” because the detection of victims is largely dependent on establishing a sufficient level of trust between them and authorities that encourages victims to self-identify. The U.S. government promotes a victim-centered approach for the detection of human trafficking. This approach requires authorities to leverage an understanding of the dynamics of exploitation to proactively search for indicators of human trafficking. Implementation of a victim-centered approach is becoming more widely accepted as the most effective means to detect trafficking victims. Mass migration, such as the current European migration crisis, introduce particularly challenging environments in which to implement a victim-centered approach. Using the migration crisis as context,  this paper presents human trafficking as a dynamic process whereby a victim’s willingness to self-identify adapts over time both spatially (e.g., due to influence from nearby neighbors) and through networks (e.g., familial, country of origin, traveling parties). We employ an agent-based model to simulate the interplay between state authorities and migrant populations in order to explore the conditions in which a victim-centered approach might succeed in detecting victims of human trafficking within large migrant encampments.. Our sensitivity analysis over a range of initial cooperation levels within the migrant population finds that a tipping point exists for when the victim-centered approach will achieve positive results. This analysis also suggests state authorities need early successes for a cooperative willingness to propagate across the population, and this willingness can persist in the system, even after border closure.  Preliminary findings also suggest a potential trade-off between more permissive immigration policies and a victim-center approach to human trafficking. This trade-off implies that more selective immigration policies might afford state authorities more time and resources to successfully employ a victim-center approach to human trafficking. 


## CREDITS AND REFERENCES

* Wilensky, U. (2005).  NetLogo Preferential Attachment model.  http://ccl.northwestern.edu/netlogo/models/PreferentialAttachment.  Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

* Wilensky, U. (1999). NetLogo. http://ccl.northwestern.edu/netlogo/. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

This model is based on:
Albert-László Barabási. Linked: The New Science of Networks, Perseus Publishing, Cambridge, Massachusetts, pages 79-92.

This model was published in Fall 2017:

Brant M. Horio and Kyle M. Ballard. Modeling a Victim-Centered Approach for Detection of Human Trafficking Victims within Migration Flows, Policy and Complex Systems. Volume 3, Number 2, Fall 2017: Washington, D.C. doi: 10.18278/jpcs.3.1.9
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

checkmark
true
0
Polygon -7500403 true true 30 150 45 195 135 285 255 60 195 15 120 240 75 150

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

victim_identified
false
0
Circle -7500403 true true 15 15 270
Circle -16777216 true false 30 30 240
Polygon -7500403 true true 30 150 120 255 150 225 90 150
Polygon -7500403 true true 120 255 240 0 300 15 150 255

victim_missed
false
0
Circle -7500403 true true 15 15 270
Circle -16777216 true false 30 30 240
Polygon -7500403 true true 0 15 285 300 300 285 15 0
Polygon -7500403 true true 0 285 285 0 300 15 15 300

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.2
@#$#@#$#@
set layout? false
set plot? false
setup repeat 300 [ go ]
repeat 100 [ layout ]
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="EconomicPolicy_withVCA" repetitions="100" runMetricsEveryStep="false">
    <setup>model.setup</setup>
    <go>model.go</go>
    <metric>g.victimPopulation</metric>
    <metric>g.victimsIdentified</metric>
    <metric>g.victimsMissed</metric>
    <metric>g.victimsWillingButMissed</metric>
    <steppedValueSet variable="gui.proportionCooperate" first="0.45" step="0.01" last="0.55"/>
    <enumeratedValueSet variable="gui.probabilityHighSkill">
      <value value="0.33"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.useSeed">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.similarityInfluenceWeighting">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.statePolicy">
      <value value="&quot;Economic&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.useVictimCentered">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.randomSeed">
      <value value="12345"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.proportionFleeing">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.migrantEntryQuota">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.proportionVictims">
      <value value="0.055"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="HumanitarianPolicy_withoutVCA" repetitions="100" runMetricsEveryStep="false">
    <setup>model.setup</setup>
    <go>model.go</go>
    <metric>g.victimPopulation</metric>
    <metric>g.victimsIdentified</metric>
    <metric>g.victimsMissed</metric>
    <metric>g.victimsWillingButMissed</metric>
    <steppedValueSet variable="gui.proportionCooperate" first="0.45" step="0.01" last="0.55"/>
    <enumeratedValueSet variable="gui.probabilityHighSkill">
      <value value="0.33"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.useSeed">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.similarityInfluenceWeighting">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.statePolicy">
      <value value="&quot;Humanitarian&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.useVictimCentered">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.randomSeed">
      <value value="12345"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.proportionFleeing">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.migrantEntryQuota">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.proportionVictims">
      <value value="0.055"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="EconomicPolicy_withoutVCA" repetitions="100" runMetricsEveryStep="false">
    <setup>model.setup</setup>
    <go>model.go</go>
    <metric>g.victimPopulation</metric>
    <metric>g.victimsIdentified</metric>
    <metric>g.victimsMissed</metric>
    <metric>g.victimsWillingButMissed</metric>
    <steppedValueSet variable="gui.proportionCooperate" first="0.45" step="0.01" last="0.55"/>
    <enumeratedValueSet variable="gui.probabilityHighSkill">
      <value value="0.33"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.useSeed">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.similarityInfluenceWeighting">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.statePolicy">
      <value value="&quot;Economic&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.useVictimCentered">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.randomSeed">
      <value value="12345"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.proportionFleeing">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.migrantEntryQuota">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.proportionVictims">
      <value value="0.055"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="HumanitarianPolicy_withVCA" repetitions="100" runMetricsEveryStep="false">
    <setup>model.setup</setup>
    <go>model.go</go>
    <metric>g.victimPopulation</metric>
    <metric>g.victimsIdentified</metric>
    <metric>g.victimsMissed</metric>
    <metric>g.victimsWillingButMissed</metric>
    <steppedValueSet variable="gui.proportionCooperate" first="0.45" step="0.01" last="0.55"/>
    <enumeratedValueSet variable="gui.probabilityHighSkill">
      <value value="0.33"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.useSeed">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.similarityInfluenceWeighting">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.statePolicy">
      <value value="&quot;Humanitarian&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.useVictimCentered">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.randomSeed">
      <value value="12345"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.proportionFleeing">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.migrantEntryQuota">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gui.proportionVictims">
      <value value="0.055"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
